@@ -11,6 +11,7 @@ from progress.bar import (Bar, ChargingBar, FillingSquaresBar,
 from progress.spinner import (Spinner, PieSpinner, MoonSpinner, LineSpinner,
                               PixelSpinner)
 from progress.counter import Counter, Countdown, Stack, Pie
+from progress.colors import bold
 
 
 def sleep():
@@ -20,9 +21,9 @@ def sleep():
 
 
 for bar_cls in (Bar, ChargingBar, FillingSquaresBar, FillingCirclesBar):
-    suffix = '%(index)d/%(max)d [%(elapsed)d / %(eta)d / %(eta_td)s]'
+    suffix = '%(index)d/%(max)d [%(elapsed)d / %(eta)d / %(eta_td)s] (%(iter_value)s)'
     bar = bar_cls(bar_cls.__name__, suffix=suffix)
-    for i in bar.iter(range(200)):
+    for i in bar.iter(range(200, 400)):
         sleep()
 
 for bar_cls in (IncrementalBar, PixelBar, ShadyBar):
@@ -32,8 +33,12 @@ for bar_cls in (IncrementalBar, PixelBar, ShadyBar):
             bar.next()
             sleep()
 
+bar = IncrementalBar(bold('Colored'), color='green')
+for i in bar.iter(range(200)):
+    sleep()
+
 for spin in (Spinner, PieSpinner, MoonSpinner, LineSpinner, PixelSpinner):
-    for i in spin(spin.__name__ + ' ').iter(range(100)):
+    for i in spin(spin.__name__ + ' %(index)d ').iter(range(100)):
         sleep()
 
 for singleton in (Counter, Countdown, Stack, Pie):
